Module container_shared_async

Module container_shared_async 

Available on crate feature shared-async only.
Container constructs allowing multiple-ownership, asynchronous, managed access to a file.

This module can be enabled with the shared-async cargo feature.

Structs

AccessGuard
A lifetime-bound, read-only access permit into a ContainerSharedAsync.
AccessGuardMut
A lifetime-bound, mutable access permit into a ContainerSharedAsync.
ContainerSharedAsync
A container that allows asynchronous atomic reference-counted, mutable access (gated by an RwLock) to the underlying file and contents. Cloning this container will not clone the underlying contents, it will clone the underlying pointer, allowing multiple-access.
OwnedAccessGuard
An owned, read-only access permit into a ContainerSharedAsync.
OwnedAccessGuardMut
An owned, mutable access permit into a ContainerSharedAsync.

Type Aliases

AtomicContainerSharedAsyncatomic
A shortcut to ContainerSharedAsync<T, AtomicManager<Format>>.
AtomicContainerSharedAsyncOptionsatomic
A shortcut to AtomicManagerOptions.
StandardContainerSharedAsync
A shortcut to ContainerSharedAsync<T, StandardManager<Format>>.
StandardContainerSharedAsyncOptions
A shortcut to StandardManagerOptions.