OrUserError

Enum OrUserError 

pub enum OrUserError<T, U> {
    Base(T),
    User(U),
}
A value that may be an error or a user-generated error.

Variants



Base(T)

An error.



User(U)

A user-generated error.

Implementations

Source

impl<T, U> OrUserError<T, U>

pub fn convert_with<E, F>(self, f: F) -> E
where T: Into<E>, F: FnOnce(U) -> E,

Converts this error into another error. The new error type E must implement From<T>. Additionally takes a closure allowing the user to decide how to convert the user error.

pub fn convert<E>(self) -> E
where T: Into<E>, U: Into<E>,

Converts this error into another error. The new error type E must implement From<T> and From<U>.

Source

impl<T> OrUserError<T, Infallible>

pub fn into_base(self) -> T

Converts this error to T (the base error variant), given that U (the user error variant) is Infallible.

Source

impl<U> OrUserError<Infallible, U>

pub fn into_user(self) -> U

Converts this error to U (the user error variant), given that T (the base error variant) is Infallible.