#[non_exhaustive]#[repr(u8)]pub enum FileMode {
Readonly = 0,
Writable = 1,
}Expand description
Describes a mode by which a file may be manipulated.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Readonly = 0
A file mode that can only read from files.
Writable = 1
A file mode that can read from and write to files.
Implementations
Sourceimpl FileMode
impl FileMode
Sourcepub const fn can_read(self) -> bool
pub const fn can_read(self) -> bool
Returns true if this FileMode is allowed to read, false otherwise.
Sourcepub const fn can_write(self) -> bool
pub const fn can_write(self) -> bool
Returns true if this FileMode is allowed to write, false otherwise.
Sourcepub const fn must_read(self) -> Result<(), OtherError>
pub const fn must_read(self) -> Result<(), OtherError>
Throws an appropriate error if this FileMode is not allowed to read.
Sourcepub const fn must_write(self) -> Result<(), OtherError>
pub const fn must_write(self) -> Result<(), OtherError>
Throws an appropriate error if this FileMode is not allowed to write.