Available on crate feature
shared-async only.Expand description
Container constructs allowing multiple-ownership, asynchronous, managed access to a file.
This module can be enabled with the shared-async cargo feature.
Structs
- Access
Guard - A lifetime-bound, read-only access permit into a
ContainerSharedAsync. - Access
Guard Mut - A lifetime-bound, mutable access permit into a
ContainerSharedAsync. - Container
Shared Async - A container that allows asynchronous atomic reference-counted, mutable access (gated by an
RwLock) to the underlying file and contents. Cloning this container will not clone the underlying contents, it will clone the underlying pointer, allowing multiple-access. - Owned
Access Guard - An owned, read-only access permit into a
ContainerSharedAsync. - Owned
Access Guard Mut - An owned, mutable access permit into a
ContainerSharedAsync.
Type Aliases
- Atomic
Container Shared Async atomic - A shortcut to
ContainerSharedAsync<T, AtomicManager<Format>>. - Atomic
Container Shared Async Options atomic - A shortcut to
AtomicManagerOptions. - Standard
Container Shared Async - A shortcut to
ContainerSharedAsync<T, StandardManager<Format>>. - Standard
Container Shared Async Options - A shortcut to
StandardManagerOptions.