pub enum OrUserError<T, U> {
Base(T),
User(U),
}Expand description
A value that may be an error or a user-generated error.
Variants
Implementations
Sourceimpl<T, U> OrUserError<T, U>
impl<T, U> OrUserError<T, U>
Sourcepub fn convert_with<E, F>(self, f: F) -> E
pub fn convert_with<E, F>(self, f: F) -> E
Converts this error into another error.
The new error type E must implement From<T>.
Additionally takes a closure allowing the user to decide how to convert the user error.
Sourceimpl<T> OrUserError<T, Infallible>
impl<T> OrUserError<T, Infallible>
Sourcepub fn into_base(self) -> T
pub fn into_base(self) -> T
Converts this error to T (the base error variant), given that U (the user error variant) is Infallible.
Sourceimpl<U> OrUserError<Infallible, U>
impl<U> OrUserError<Infallible, U>
Sourcepub fn into_user(self) -> U
pub fn into_user(self) -> U
Converts this error to U (the user error variant), given that T (the base error variant) is Infallible.